<?php
// $Id$

/**
 * @file
 * OM Tools Admin Utilities
 *
 * @author: Daniel Honrade http://drupal.org/user/351112
 *
 */
 
/**
 * OM Tools alter forms processor
 *
 */
function om_tools_alter(&$form, &$form_state, $form_id) { 
  $om_tools_values = variable_get('om_tools', '');
  
  $tools = om_tools_get();
  foreach ($tools as $key => $module) {
    $form['om_' . $module . '_tools_values']['#type'] = 'hidden';      
    $form['om_' . $module . '_tools_values']['#value'] = isset($om_tools_values[$module]) ? $om_tools_values[$module]: '';          
    include_once(drupal_get_path('module', 'om_tools') . '/tools/' . $module . '/' . $module . '.inc');
    $function = 'om_' . $module . '_alter';
    if (function_exists($function)) $function($form, $form_state, $form_id);
    // this avoids inclusion in the actual output of form
    unset($form['om_' . $module . '_tools_values']);  
  }
} 


/**
 * OM Tools processor
 *
 */
function om_tools_processor(&$vars, $process = NULL) {
  $om_tools_values = variable_get('om_tools', '');
  //dsm($om_tools_values);  

  $tools = om_tools_get();
  foreach ($tools as $key => $module) {
    $vars['om_' . $module . '_tools_values'] = isset($om_tools_values[$module]) ? $om_tools_values[$module]: '';  
    include_once(drupal_get_path('module', 'om_tools') . '/tools/' . $module . '/' . $module . '.inc');
    $function = 'om_' . $module . '_' . $process;
    if (function_exists($function)) $function($vars);
    // this avoids inclusion in the actual output of form
    if (isset($vars['om_' . $module . '_tools_values'])) unset($vars['om_' . $module . '_tools_values']);  
  }
}


/**
 * OM Tools get file names from /tools directory
 * - reads directory names
 */
function om_tools_get() {
  $files = array();
  $dir = drupal_get_path('module', 'om_tools') . '/tools/';
  $folders = scandir($dir);
  $excluded_files = array('.', '..', '.cvs', '.svn', '.git');
  
  foreach ($folders as $key => $val) {
		if (!in_array($val, $excluded_files)) (is_dir($dir . $val)) ? $files[] = $val: '';
  }
  return $files;
}

/**
 * Safe classes
 */
function om_tools_class_safe($string) {
  // Replace with dashes anything that isn't A-Z, numbers, dashes, or underscores.
  $string = preg_replace('/-/', ' ', $string);    
  $string = trim(preg_replace('/\s+/', ' ', $string));   
  return strtolower(preg_replace('/[^a-zA-Z0-9-]+/', '-', $string));
}

/**
 * Admin - hide/show tool forms
 *
 */
function om_tools_admin_js($subtools = array()) {
  $add_js = '';
  
  $add_js .= "jQuery(document).ready(function($){";
      
  foreach ($subtools as $key => $subtool) {    
    $add_js .= "om_set_switch('" . $subtool . "');";
  }

  $add_js .= "
	    function om_set_switch(idname) {
        $('#edit-' + idname + '-switch').change(
          function() {
            if ($('#edit-' + idname + '-switch').attr('checked') == '') {
              $('#om-group-' + idname + '-settings').css('display', 'none');
            } else  {
              $('#om-group-' + idname + '-settings').css('display', 'block');
            }
          }
        );
        if ($('#edit-' + idname + '-switch').attr('checked') == '') {
          $('#om-group-' + idname + '-settings').css('display', 'none');
        } else {
          $('#om-group-' + idname + '-settings').css('display', 'block');
        }	
	    }
    }); ";
  
  drupal_add_js($add_js, "inline");
}

